<h1 align="center">
<img src="https://raw.githubusercontent.com/jgherruzo/pyPETB/main/logo/current/pyPETB_logo.png" width="300">
</h1><br>

# THE PROCESS ENGINEER TOOLBOX

[![python](https://img.shields.io/badge/python-3.11-blue.svg?logo=python)](https://www.python.org)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Process Engineer Tool Box is a package where a set of tools are developed to help in our daily tasks. It is based in the use of pandas. In daily chemical industry task, focused on data analysis
and improvement projects developing, no long dataset are
usually used and pandas cover all the requirements.

## 2- INSTALLATION

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pyPETB.

```bash
pip install pyPETB
```

## 3- USAGE

Please refer to the [Documentation](https://pypetb.readthedocs.io/en/latest/)

## 4- LICENSE

Distributed under the [MIT License](https://github.com/jgherruzo/pyPETB/blob/main/LICENSE.txt).

## 5- ROADMAP

- V0.1 RnRnumeric class to analyze numerical measurement system --> Available
- V0.2 Capability class to make process capability analysis --> On going
- V0.3 RnRcat class to analyze categorical measurement system (Atributes)
- V0.4 DOE class to analyze DOE results
- V1.1 Periodic Table class (Very useful for V1.2 release)
- V1.2 MEB class for develop material and energy balances

## 6- ACKNOLEDGMENTS

- Thanks to Noël Santiago for his coaching during our six sigma green belt training
- Thanks to Alexandre Baharov for sharing the statistic tables script
- Thanks to Ted Hessing for his detailed article calculating RnR:
https://sixsigmastudyguide.com/repeatability-and-reproducibility-rr/

![Visual Studio Code](https://img.shields.io/badge/Visual%20Studio%20Code-blue?logo=visual%20studio%20code)
![Poetry](https://img.shields.io/badge/Poetry-blue?logo=poetry)
![ReadTheDocs](https://img.shields.io/badge/ReadTheDocs-blue?logo=readthedocs)
